@@ -114,6 +114,8 @@ class HouseMapper(ObjectMapper):
         'adm_parent_guid': 'hierarchy__adm__parentobjid__objectguid',
         'mun_parent_obj_id': 'hierarchy__mun__parentobjid__objectid',
         'mun_parent_guid': 'hierarchy__mun__parentobjid__objectguid',
+        'number': 'number',
+        'house_type': 'house_type',
     }
 
     assert set(fields_map) == set(House.fields)
