@@ -482,6 +482,16 @@ class House(ObjectBase):
             required=False,
             description='Родительский guid в муниципальной иерархии'
         ),
+        'number': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description=''
+        ),
+        'house_type': FieldDescriptor(
+            data_type=_int,
+            required=False,
+            description=''
+        ),
     }
 
 
