@@ -674,14 +674,18 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
 
         this.houseIDField.setValue(record.get('objectId'));
 
-        this.houseTypeField.setValue(record.get('houseType'))
+        this.houseTypeField.setValue(record.get('houseType'));
 
         if (record.get('houseNumber')) {
-            this.houseNumberField.setValue(record.get('houseNumber'))
-            this.flatNumberField.setReadOnly(false);
+            this.houseNumberField.setValue(record.get('houseNumber'));
+            if (this.flatNumberField && this.flatNumberField.rendered) {
+                this.flatNumberField.setReadOnly(false);
+            }
         } else if (record.get('steadNumber')) {
             this.houseNumberField.setValue('уч. ' + record.get('steadNumber'));
-            this.flatNumberField.setReadOnly(true);
+            if (this.flatNumberField && this.flatNumberField.rendered) {
+                this.flatNumberField.setReadOnly(true);
+            }
         }
         else {
             throw new this.UserException('Ошибка.', 'Не удалось получить номер дома или земельного участка.')
